@@ -28,9 +28,9 @@ logger = logging.getLogger(__file__)
 class ClickHouseConnector:
     @dataclass
     class BaseConfig:
-        database: str
-        login: str
-        password: str
+        database: str = "default"
+        login: str = "default"
+        password: str = ""
 
     @dataclass
     class Config(HttpServerConnector.Config, BaseConfig):
@@ -41,6 +41,7 @@ class ClickHouseConnector:
     def __init__(self, config: Config, context: Context):
         self.config = config
         self._http_connector = HttpServerConnector(config, context)
+
     @retry(attempts_limit=2, sleep_time_sec=2.0)
     async def execute(self, sql: str) -> str:
         logger.debug(f'sql({sql}):')
@@ -74,7 +75,7 @@ class ClickHouseConnector:
                      ) -> list:
         result = await self.execute_statement(
             statement=Select(
-                table, selectables, condition, group_by,
+                self.config.database, table, selectables, condition, group_by,
                 order_by, offset, limit, output_format, distinct_on
             )
         )
@@ -86,11 +87,11 @@ class ClickHouseConnector:
                     filter_by: List[Filter] | None = None,
                     search_by: List[Filter] | None = None,
                     ) -> int:
-        result = await self.execute_statement(statement=Count(table, filter_by, search_by))
+        result = await self.execute_statement(statement=Count(self.config.database, table, filter_by, search_by))
         return result.fetchone()
 
     async def insert(self, data_to_insert: List[Table]) -> None:
-        await self.execute_statement(statement=Insert(data_to_insert))
+        await self.execute_statement(statement=Insert(self.config.database, data_to_insert))
 
     async def create_table(self, table: Type[Table]) -> None:
-        await self.execute_statement(statement=CreateTable(table))
+        await self.execute_statement(statement=CreateTable(self.config.database, table))
