@@ -1,7 +1,11 @@
 from abc import ABC, abstractmethod
+from dataclasses import dataclass
 
 
+@dataclass
 class AbstractStatement(ABC):
+    database: str
+
     @abstractmethod
     def generate_sql(self) -> str:
         ...
