@@ -1,5 +1,5 @@
 from dataclasses import dataclass, field
-from typing import Type, Optional, List, NoReturn
+from typing import Type, Optional, List
 
 from ..elements.filter_by import Filter
 from ..elements.result import CountResult
@@ -14,7 +14,7 @@ class Count(AbstractStatement):
     filter_by: Optional[List[Filter]] = field(default_factory=list)
     search_by: Optional[List[Filter]] = field(default_factory=list)
 
-    def generate_sql(self):
+    def generate_sql(self) -> str:
         table_name = self.table.get_name()
 
         where_filter_part = ' AND '.join((str(f) for f in self.filter_by) if self.filter_by is not None else [])
@@ -27,7 +27,7 @@ class Count(AbstractStatement):
         full_where = where_filter_part + where_parts_union_connector + where_search_part
         where_sql = f'\nWHERE {full_where}' if full_where else ''
 
-        return f"SELECT COUNT(*) FROM {table_name} {where_sql}"
+        return f"SELECT COUNT(*) FROM {self.database}.{table_name} {where_sql}"
 
     def form_result(self, payload: str) -> CountResult:
         return CountResult(payload)
