@@ -9,7 +9,7 @@ from ..statements.abstract_statement import AbstractStatement
 class CreateTable(AbstractStatement):
     table: Type[Table]
 
-    def generate_sql(self):
+    def generate_sql(self) -> str:
         table_name = self.table.get_name()
 
         table_column_descriptors = [column.to_column_descriptor() for column in self.table.get_columns()]
@@ -25,7 +25,7 @@ class CreateTable(AbstractStatement):
 
         table_primary_keys_string = ', '.join(self.table.get_primary_key_names())
 
-        create_string = f"CREATE TABLE IF NOT EXISTS {table_name}\n " \
+        create_string = f"CREATE TABLE IF NOT EXISTS {self.database}.{table_name}\n " \
                         f"(\n{table_columns_string}\n) " \
                         f"ENGINE = {engine_string} \n" \
                         f"{table_partition_keys_string}" \
