@@ -28,14 +28,13 @@ class Select(AbstractStatement, Sqlable):
     output_format: OutputFormat = OutputFormat.Dict
     distinct_on: list[Selectable] | Selectable | None = field(default_factory=list)
 
-
     def __post_init__(self):
         self.table.get_table_engine().preprocess_select_request(self)
-
         self.selectables = to_list(self.selectables) if self.selectables is not None else []
         self.distinct_on = to_list(self.distinct_on) if self.distinct_on is not None else []
         self.group_by = to_list(self.group_by) if self.group_by is not None else []
         self.order_by = to_list(self.order_by) if self.order_by is not None else []
+
     def to_sql(self) -> str:
         return self.generate_sql()
 
@@ -48,8 +47,7 @@ class Select(AbstractStatement, Sqlable):
         else:
             raise ValueError(f'unexpected {self.select_from=}')
 
-    def generate_sql(self):
-
+    def generate_sql(self) -> str:
         select_sql = self._construct_select_sql()
         from_sql = self._construct_from_sql()
         distinct_on_sql = self._construct_distinct_on_sql()
@@ -62,11 +60,12 @@ class Select(AbstractStatement, Sqlable):
         logger.debug(f"constructed {sql=}")
         return sql
 
-
-    def _construct_from_sql(self):
+    def _construct_from_sql(self) -> str:
         sql = self.select_from.to_sql()
         if isinstance(self.select_from, Select):
             sql = f"({sql})"
+        else:
+            sql = f"{self.database}.{sql}"
         return sql
 
     def _construct_select_sql(self) -> str:
@@ -80,6 +79,7 @@ class Select(AbstractStatement, Sqlable):
             distinct_on_sql = \
                 f"DISTINCT ON({', '.join(selectable.to_selector() for selectable in self.distinct_on)}) "
         return distinct_on_sql
+
     def _construct_where_sql(self) -> str:
         return f'\nWHERE {self.condition.to_sql()}' if self.condition else ''
 
